@@ -4,6 +4,7 @@ import gi
 import logbook
 from logbook.handlers import Handler, StringFormatterHandlerMixin
 
+
 gi.require_version('GLib', '2.0')
 
 from gi.repository import GLib  # pyright: ignore[reportMissingModuleSource]
@@ -23,9 +24,12 @@ LOGBOOK_LEVEL_TO_GLIB = {
 def _log(level: GLib.LogLevelFlags, message: str):
     variant_message = GLib.Variant('s', message)
 
-    variant_dict = GLib.Variant('a{sv}', {
-        'MESSAGE': variant_message,
-    })
+    variant_dict = GLib.Variant(
+        'a{sv}',
+        {
+            'MESSAGE': variant_message,
+        },
+    )
     GLib.log_variant(SHORT_NAME, level, variant_dict)
 
 
